@@ -51,14 +51,14 @@ package com.openexchange.documentconverter.client.impl;
 
 import java.io.File;
 import java.io.InputStream;
+import java.net.URL;
 import java.util.HashMap;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
+import com.openexchange.documentconverter.DocumentConverterManager;
 import com.openexchange.documentconverter.LogData;
-import com.openexchange.documentconverter.ManagerBasics;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.Properties;
-import com.openexchange.documentconverter.ServerType;
 
 /**
  * {@link ManagedClientHashJob}
@@ -72,8 +72,8 @@ public class ManagedClientHashJob extends ManagedClientJob {
      * Initializes a new {@link ManagedClientHashJob}.
      * @param manager
      */
-    public ManagedClientHashJob(ClientManager manager, ServerType serverType) {
-        super(manager, serverType);
+    public ManagedClientHashJob(final ClientManager manager, final URL remoteUrl) {
+        super(manager, remoteUrl);
     }
 
     /* (non-Javadoc)
@@ -90,20 +90,21 @@ public class ManagedClientHashJob extends ManagedClientJob {
         InputStream ret = null;
 
         if ((null != jobType) && (null != fileBasedJobProperties)) {
-            final boolean logTrace = ClientManager.isLogTrace();
             final Boolean asyncObject = (Boolean) fileBasedJobProperties.get(Properties.PROP_ASYNC);
             final boolean isAsyncRequest = (null != asyncObject) && asyncObject.booleanValue();
             HashMap<String, Object> hashedJobProperties = getHashedJobProperties(jobType, fileBasedJobProperties, isAsyncRequest);
             String remoteCacheHash = null;
             boolean queryResultAvailability = false;
+            final boolean trace = DocumentConverterManager.isLogTrace();
+            long traceStartTimeMillis = 0;
 
-            if (logTrace) {
-                ClientManager.logTrace("DC received request for " + (isAsyncRequest ? "async " : "") + "conversion", fileBasedJobProperties);
+            if (trace) {
+                traceStartTimeMillis = System.currentTimeMillis();
+                DocumentConverterManager.logTrace("DC received request for " + (isAsyncRequest ? "async " : "") + "conversion", fileBasedJobProperties);
             }
 
             // try to get a valid result from a remotehash request first
             if (null != hashedJobProperties) {
-                long startTime = logTrace ? System.currentTimeMillis() : 0;
                 final String infoFileName = (String) hashedJobProperties.get(Properties.PROP_INFO_FILENAME);
                 final Boolean queryAvailability = (Boolean) hashedJobProperties.get(Properties.PROP_QUERY_AVAILABILITY);
 
@@ -111,34 +112,34 @@ public class ManagedClientHashJob extends ManagedClientJob {
                 remoteCacheHash = (String) hashedJobProperties.get(Properties.PROP_REMOTE_CACHE_HASH);
 
                 if (queryResultAvailability) {
-                    if (logTrace) {
-                        ClientManager.logTrace("DC remotehash client query for asynchronous request initiated",
+                    if (trace) {
+                        DocumentConverterManager.logTrace("DC remotehash client query for asynchronous request initiated",
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"));
                     }
 
                     queryResultAvailability = super.queryAvailability(jobType, hashedJobProperties, resultProperties);
 
-                    if (logTrace) {
-                        ClientManager.logTrace("DC remotehash client query for asynchronous request " + (queryResultAvailability ? "succeeded" : "failed"),
+                    if (trace) {
+                        DocumentConverterManager.logTrace("DC remotehash client query for asynchronous request " + (queryResultAvailability ? "succeeded" : "failed"),
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"),
-                            new LogData("exectime", Long.toString(System.currentTimeMillis() - startTime) + "ms"));
+                            new LogData("exectime", Long.toString(System.currentTimeMillis() - traceStartTimeMillis) + "ms"));
                     }
                 } else {
-                    if (logTrace) {
-                        ClientManager.logTrace("DC remotehash client request initiated",
+                    if (trace) {
+                        DocumentConverterManager.logTrace("DC remotehash client request initiated",
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"));
                     }
 
                     ret = super.process(jobType, hashedJobProperties, resultProperties);
 
-                    if (logTrace) {
-                        ClientManager.logTrace("DC remotehash client request " + ((null != ret) ? "succeeded" : "failed"),
+                    if (trace) {
+                        DocumentConverterManager.logTrace("DC remotehash client request " + ((null != ret) ? "succeeded" : "failed"),
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"),
-                            new LogData("exectime", Long.toString(System.currentTimeMillis() - startTime) + "ms"));
+                            new LogData("exectime", Long.toString(System.currentTimeMillis() - traceStartTimeMillis) + "ms"));
                     }
                 }
             }
@@ -298,7 +299,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
      * @return
      */
     static StringBuilder getDefaultPseudoHashBuilder(@NonNull String jobType, @NonNull HashMap<String, Object> jobProperties, @NonNull File jobInputFile) {
-        return ManagerBasics.getFileHashBuilder(jobInputFile, (String) jobProperties.get(Properties.PROP_LOCALE)).append(jobType);
+        return DocumentConverterManager.getFileHashBuilder(jobInputFile, (String) jobProperties.get(Properties.PROP_LOCALE)).append(jobType);
     }
 
     /**
@@ -307,7 +308,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
      * @return
      */
     static HashMap<String, Object> createFileBasedJobProperties(HashMap<String, Object> jobProperties, boolean[] deleteInputFileProperty) {
-        final File jobInputFile = ManagerBasics.getJobInputFile(jobProperties, deleteInputFileProperty);
+        final File jobInputFile = DocumentConverterManager.getJobInputFile(jobProperties, deleteInputFileProperty);
         HashMap<String, Object> fileBasedJobProperties = null;
 
         // ensure, that we always have a file based job property set to work on
