@@ -54,6 +54,7 @@ import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileInputStream;
+import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.ObjectInputStream;
@@ -63,7 +64,6 @@ import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLEncoder;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
@@ -74,14 +74,16 @@ import org.apache.commons.lang.StringUtils;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.json.JSONTokener;
+import com.openexchange.documentconverter.DocumentConverterManager;
+import com.openexchange.documentconverter.DocumentInformation;
+import com.openexchange.documentconverter.HttpHelper;
+import com.openexchange.documentconverter.HttpResponseProcessor;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
 import com.openexchange.documentconverter.LogData;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.documentconverter.ServerType;
-import com.openexchange.documentconverter.TransferHelper;
 import com.openexchange.documentconverter.TransferObject;
-import com.openexchange.documentconverter.TransferResponseProcessor;
 
 /**
  * {@link ManagedClientJob}
@@ -95,27 +97,11 @@ class ManagedClientJob {
      *
      * @param clientManager
      */
-    ManagedClientJob(ClientManager clientManager, ServerType serverType) {
+    ManagedClientJob(final ClientManager clientManager, final URL remoteUrl) {
         super();
 
         m_clientManager = clientManager;
-        m_serverType = serverType;
-
-        final boolean hasRemoteServer = clientManager.hasRemoteServer(serverType);
-
-        if (hasRemoteServer) {
-            switch (m_serverType) {
-                case DOCUMENTCONVERTER: {
-                    m_remoteUrl = ClientManager.getClientConfig().REMOTEURL_DOCUMENTCONVERTER;
-                    break;
-                }
-
-                case CACHESERVER:
-                default: {
-                    break;
-                }
-            }
-        }
+        m_remoteUrl = remoteUrl;
     }
 
     /**
@@ -253,7 +239,7 @@ class ManagedClientJob {
                 ret = IOUtils.toByteArray(inputStm);
             }
         } catch (final Exception e) {
-            ClientManager.logExcp(e);
+            DocumentConverterManager.logExcp(e);
         }
 
         // check, if length of byte array is larger than specified config source file size
@@ -288,7 +274,7 @@ class ManagedClientJob {
         }
 
         if (ret && (null != m_remoteUrl)) {
-            ret = m_clientManager.getRemoteAPIVersion(m_serverType) >= minRemoteAPIVersion;
+            ret = m_clientManager.getRemoteAPIVersion() >= minRemoteAPIVersion;
         }
 
         return ret;
@@ -364,7 +350,7 @@ class ManagedClientJob {
      * @return true, if source size is larger than max size
      */
     protected static boolean setSourceFileSizeError(long sourceSize, final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
-        final long maxSize = ClientManager.getClientConfig().MAX_DOCUMENT_SOURCEFILESIZE;
+        final long maxSize = ClientManager.get().getClientConfig().MAX_DOCUMENT_SOURCEFILESIZE;
         boolean ret = false;
 
         if (sourceSize > maxSize) {
@@ -373,8 +359,8 @@ class ManagedClientJob {
             if (null != resultProperties) {
                 resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.MAX_SOURCESIZE.errorCode()));
 
-                if (ClientManager.isLogError()) {
-                    ClientManager.logError("DC detected source file size larger than configured size",
+                if (DocumentConverterManager.isLogError()) {
+                    DocumentConverterManager.logError("DC detected source file size larger than configured size",
                         jobProperties,
                         new LogData("sourcesize", (new Long(sourceSize)).toString()),
                         new LogData("maxsize", (new Long(maxSize)).toString()));
@@ -392,9 +378,9 @@ class ManagedClientJob {
      * @return true, if source size is larger than max size
      */
     protected static boolean setSupportedTypeError(String inputType, final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
-        final Set<String> supportedTypes = ClientManager.getClientConfig().SUPPORTED_TYPES;
+        final Set<String> supportedTypes = ClientManager.get().getClientConfig().SUPPORTED_TYPES;
         final boolean ret = (supportedTypes.size() > 0) &&
-            SUPPORTED_TYPE_CHECK_LIST.contains(inputType) &&
+            DocumentInformation.isExtensionSupported(inputType) &&
             !supportedTypes.contains(inputType);
 
         if (ret) {
@@ -402,8 +388,8 @@ class ManagedClientJob {
                 resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.UNSUPPORTED.errorCode()));
             }
 
-            if (ClientManager.isLogError()) {
-                ClientManager.logError("DC detected unsupported input file extension",
+            if (DocumentConverterManager.isLogError()) {
+                DocumentConverterManager.logError("DC detected unsupported input file extension",
                     jobProperties, new LogData("inputype", inputType));
             }
         }
@@ -425,7 +411,7 @@ class ManagedClientJob {
             try {
                 calledRemoteUrl = new URL(calledRemoteUrlString);
             } catch (final MalformedURLException e) {
-                ClientManager.logExcp(e);
+                DocumentConverterManager.logExcp(e);
             }
         }
 
@@ -460,6 +446,7 @@ class ManagedClientJob {
      */
     private Object doRemoteCall(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
         Object ret = null;
+        final HttpHelper httpHelper = HttpHelper.get();
         final boolean isMultipartRequest = (jobProperties.containsKey(Properties.PROP_INPUT_FILE) || jobProperties.containsKey(Properties.PROP_INPUT_STREAM));
         final Boolean asyncJob = (Boolean) jobProperties.get(Properties.PROP_ASYNC);
         final Boolean remoteAsyncJob = (Boolean) jobProperties.get(Properties.PROP_REMOTE_ASYNC);
@@ -468,52 +455,61 @@ class ManagedClientJob {
         final boolean isAsync = ((null != asyncJob) && asyncJob.booleanValue()) || ((null != remoteAsyncJob) && remoteAsyncJob.booleanValue());
         final boolean isCacheOnly = (null != cacheOnlyJob) && cacheOnlyJob.booleanValue();
         final String remoteParams = isMultipartRequest ? getRemoteParams(jobProperties, resultProperties, false, "returntype=binary") : getRemoteParams(jobProperties, resultProperties, true);
-        final boolean logTrace = ClientManager.isLogTrace();
+        final boolean logTrace = DocumentConverterManager.isLogTrace();
         final String remoteMethod = jobProperties.containsKey(Properties.PROP_REMOTE_METHOD) ? (String) jobProperties.get(Properties.PROP_REMOTE_METHOD) : "";
         final String logTitle = (remoteMethod.equals("transformimage")) ?
             ("ImageServer " + (isAsync ? "asynchronous " : "") + "remote transformation") :
                 ("DC " + (isAsync ? "asynchronous " : "") + "remote conversion");
 
-            if ((null != m_remoteUrl) && (null != remoteParams)) {
+            if ((null != httpHelper) && (null != m_remoteUrl) && (null != remoteParams)) {
                 final String callCookie = (String) jobProperties.get(Properties.PROP_CONVERTER_COOKIE);
                 URL remoteUrl = null;
 
                 if (logTrace) {
-                    ClientManager.logTrace(logTitle + " initiated", jobProperties, new LogData("method", remoteMethod));
+                    DocumentConverterManager.logTrace(logTitle + " initiated", jobProperties, new LogData("method", remoteMethod));
                 }
 
                 try {
                     remoteUrl = new URL(m_remoteUrl.toString() + "?action=rconvert");
                 } catch (final MalformedURLException e) {
-                    ClientManager.logExcp(e);
+                    DocumentConverterManager.logExcp(e);
+                    return ret;
                 }
 
-                if ((null != remoteUrl) && isMultipartRequest) {
-                    final String inputType = (String) jobProperties.get(Properties.PROP_INPUT_TYPE);
-                    final String inputMimeType = (null != inputType) && (inputType.equals("pdf")) ? "application/pdf" : "application/octet-stream";
-                    final Serializable contentSerializable =  jobProperties.containsKey(Properties.PROP_INPUT_FILE) ?
-                        (File) jobProperties.get(Properties.PROP_INPUT_FILE) :
-                            getInputBuffer(jobProperties, resultProperties);
+                try {
+                    if (isMultipartRequest) {
+                        final String inputType = (String) jobProperties.get(Properties.PROP_INPUT_TYPE);
+                        final String inputMimeType = "pdf".equals(inputType) ? "application/pdf" : "application/octet-stream";
+                        final Serializable contentSerializable =  jobProperties.containsKey(Properties.PROP_INPUT_FILE) ?
+                            (File) jobProperties.get(Properties.PROP_INPUT_FILE) :
+                                getInputBuffer(jobProperties, resultProperties);
 
 
-                    if (null != contentSerializable) {
-                        final TransferObject<Serializable> transferObject = new TransferObject<>(
-                            remoteParams,
-                            contentSerializable,
-                            "ByteArray.bin",
-                            inputMimeType,
-                            callCookie);
-                        final TransferHelper.PostFormDataMode postFormDataMode =
-                            ((contentSerializable instanceof File) && (m_clientManager.getRemoteAPIVersion(ServerType.DOCUMENTCONVERTER) >= 6)) ?
-                            TransferHelper.PostFormDataMode.FILE_LENGTH_AND_DATA :
-                                TransferHelper.PostFormDataMode.BYTEARRAY_OBJECT;
+                        if (null != contentSerializable) {
+                            final int remoteAPIVersion = m_clientManager.getRemoteAPIVersion();
+                            final TransferObject<Serializable> transferObject = new TransferObject<>(
+                                remoteParams,
+                                contentSerializable,
+                                "ByteArray.bin",
+                                inputMimeType,
+                                callCookie);
+                            final HttpHelper.TransferDataMode transferDataMode =
+                                (remoteAPIVersion >= 8) ?
+                                    HttpHelper.TransferDataMode.OCTET_STREAM :
+                                        (((contentSerializable instanceof File) && (remoteAPIVersion >= 6)) ?
+                                            HttpHelper.TransferDataMode.FILE_LENGTH_AND_DATA :
+                                                HttpHelper.TransferDataMode.BYTEARRAY_OBJECT);
 
-                        TransferHelper.postFormData(m_clientManager, remoteUrl, m_serverType, transferObject, postFormDataMode, new TransferResponseProcessor() {
+                            httpHelper.postFormData(m_clientManager,
+                                remoteUrl,
+                                ServerType.DOCUMENTCONVERTER,
+                                transferObject,
+                                transferDataMode,
+                                new HttpResponseProcessor() {
 
-                            @SuppressWarnings("unchecked")
-                            @Override
-                            public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
-                                try {
+                                @SuppressWarnings("unchecked")
+                                @Override
+                                public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
                                     // evaluate result only for synchronous calls with valid result stream
                                     if (!isAsync && (null != responseInputStream)) {
                                         try (ObjectInputStream objInputStream = new ObjectInputStream(new BufferedInputStream(responseInputStream))) {
@@ -536,30 +532,30 @@ class ManagedClientJob {
                                             }
                                         } catch (final Exception e) {
                                             resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.TIMEOUT.errorCode()));
-                                            ClientManager.logExcp(e);
+                                            DocumentConverterManager.logExcp(e);
                                         }
                                     }
-                                } finally {
-                                    IOUtils.closeQuietly(responseInputStream);
                                 }
+                            });
+
+                            final byte[] resultBuffer = (byte[]) resultProperties.get(Properties.PROP_RESULT_BUFFER);
+
+                            if (null != resultBuffer) {
+                                ret = new ByteArrayInputStream(resultBuffer);
                             }
-                        });
-
-                        final byte[] resultBuffer = (byte[]) resultProperties.get(Properties.PROP_RESULT_BUFFER);
-
-                        if (null != resultBuffer) {
-                            ret = new ByteArrayInputStream(resultBuffer);
                         }
-                    }
-                } else {
-                    final TransferObject<byte[]> transferObject = new TransferObject<>(remoteParams, callCookie);
-                    final StringBuilder response = new StringBuilder();
+                    } else {
+                        final TransferObject<byte[]> transferObject = new TransferObject<>(remoteParams, callCookie);
+                        final StringBuilder response = new StringBuilder();
 
-                    TransferHelper.postRequest(m_clientManager, remoteUrl, m_serverType, transferObject, new TransferResponseProcessor() {
+                        httpHelper.postRequest(m_clientManager,
+                            remoteUrl,
+                            ServerType.DOCUMENTCONVERTER,
+                            transferObject,
+                            new HttpResponseProcessor() {
 
-                        @Override
-                        public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
-                            try {
+                            @Override
+                            public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
                                 // evaluate result only for synchronous calls with valid result stream
                                 if (!isAsync && (null != responseInputStream)) {
                                     try (BufferedReader inputReader = new BufferedReader(new InputStreamReader(responseInputStream))) {
@@ -572,36 +568,40 @@ class ManagedClientJob {
                                         }
                                     } catch (final Exception e) {
                                         resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.TIMEOUT.errorCode()));
-                                        ClientManager.logExcp(e);
+                                        DocumentConverterManager.logExcp(e);
                                     }
                                 }
-                            } finally {
-                                IOUtils.closeQuietly(responseInputStream);
+                            }
+                        });
+
+                        // parse JSON response only on case of synchronous jobs,
+                        // since we won't get a valid answer for async requests
+                        if (!isAsync) {
+                            try {
+                                ret = parseJSONResponse(new JSONObject(new JSONTokener(response.toString())), resultProperties);
+                            } catch (final JSONException e) {
+                                DocumentConverterManager.logExcp(e);
                             }
                         }
-                    });
-
-                    // parse JSON response only on case of synchronous jobs,
-                    // since we won't get a valid answer for async requests
-                    if (!isAsync) {
-                        try {
-                            ret = parseJSONResponse(new JSONObject(new JSONTokener(response.toString())), resultProperties);
-                        } catch (final JSONException e) {
-                            ClientManager.logExcp(e);
-                        }
                     }
+                } catch (Exception e) {
+                    if (e instanceof IOException) {
+                        m_clientManager.resetRemoteConnection();
+                    }
+
+                    DocumentConverterManager.logExcp(e);
                 }
             }
 
             if (isAsync) {
                 if (logTrace) {
-                    ClientManager.logTrace(logTitle + " implicitly succeeded", jobProperties);
+                    DocumentConverterManager.logTrace(logTitle + " implicitly succeeded", jobProperties);
                 }
             } else if (JobError.NONE == JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE))) {
                 if (logTrace) {
-                    ClientManager.logTrace(logTitle + " succeeded", jobProperties);
+                    DocumentConverterManager.logTrace(logTitle + " succeeded", jobProperties);
                 }
-            } else if (ClientManager.isLogWarn()) {
+            } else if (DocumentConverterManager.isLogWarn()) {
                 // don't log warnings for cacheOnly jobs /
                 // don't log warnings for async jobs /
                 // don't log warnings for remote cachehash jobs
@@ -615,12 +615,15 @@ class ManagedClientJob {
                     final StringBuilder errorMessageBuilder = new StringBuilder("DC received a remote conversion ");
                     final JobError jobError = JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
 
-                    ClientManager.logWarn(errorMessageBuilder.append(
+                    DocumentConverterManager.logWarn(errorMessageBuilder.append(
                         (JobError.TIMEOUT == jobError) ? "timeout error" :
                             (JobError.NO_CONTENT == jobError) ? "no content error" :
                                 (JobError.PASSWORD == jobError) ? "password error" :
                                     (JobError.MAX_SOURCESIZE == jobError) ? "max source size error" :
-                                        "general error").toString());
+                                        (JobError.OUT_OF_MEMORY == jobError) ? "out of memory error" :
+                                            (JobError.ABORT == jobError) ? "abort error" :
+                                                (JobError.PDFTOOL == jobError) ? "PDFTool error" :
+                                                "general error").toString());
                 }
             }
 
@@ -729,7 +732,7 @@ class ManagedClientJob {
                 try {
                     paramBuilder.append("&infofilename=").append(URLEncoder.encode(infoFileName, "UTF-8"));
                 } catch (final UnsupportedEncodingException e) {
-                    ClientManager.logExcp(e);
+                    DocumentConverterManager.logExcp(e);
                 }
             }
 
@@ -778,6 +781,11 @@ class ManagedClientJob {
                 paramBuilder.append("&imagescaletype=").append((String) curParam);
             }
 
+            // UserRequest
+            if (null != (curParam = jobProperties.get(Properties.PROP_USER_REQUEST))) {
+                paramBuilder.append("&userrequest=").append(((Boolean) curParam).toString());
+            }
+
             // RemoteUrl
             paramBuilder.append("&remoteurl=").append(m_remoteUrl.toString());
 
@@ -796,7 +804,7 @@ class ManagedClientJob {
 
                 if (null != inputBuffer) {
                     final String inputType = (String) jobProperties.get(Properties.PROP_INPUT_TYPE);
-                    final String inputMimeType = (null != inputType) && (inputType.equals("pdf")) ? "application/pdf" : "application/octet-stream";
+                    final String inputMimeType = "pdf".equals(inputType) ? "application/pdf" : "application/octet-stream";
 
                     try {
                         final String base64String = Base64.encodeBase64URLSafeString(inputBuffer);
@@ -805,7 +813,7 @@ class ManagedClientJob {
                             paramBuilder.append("&url=data:").append(inputMimeType).append(";base64,").append(base64String);
                         }
                     } catch (final Exception e) {
-                        ClientManager.logExcp(e);
+                        DocumentConverterManager.logExcp(e);
                         paramBuilder = null;
                     }
                 }
@@ -909,7 +917,7 @@ class ManagedClientJob {
                 }
             }
         } catch (final JSONException e) {
-            ClientManager.logExcp(e);
+            DocumentConverterManager.logExcp(e);
         }
 
         return ret;
@@ -919,8 +927,6 @@ class ManagedClientJob {
 
     protected ClientManager m_clientManager = null;
 
-    protected ServerType m_serverType = null;
-
     protected volatile boolean m_curJobDone = false;
 
     protected volatile boolean m_jobRunningStateReached = false;
@@ -946,66 +952,4 @@ class ManagedClientJob {
     protected static final String RCALL_ENDPAGECONVERSION = "endpageconversion";
 
     protected static Map<String, String> m_converterCookieMap = new ConcurrentHashMap<>();
-
-    protected static final Set<String> SUPPORTED_TYPE_CHECK_LIST = new HashSet<>();
-
-    {
-        // List of all supported types
-        // csv,doc,docm,docx,docxm,dot,dotm,dotx,dotxm,fodp,fods,fodt,html,odg,odgm,odp,odpm,ods,odsm,odt,odtm,otg,otgm,otm,ots,otsm,odtm,otgm,otp,otpm,ott,ottm,pot,potm,potx,pps,ppt,pptm,pptx,rtf,txt,xlm,xls,xlsm,xlst,xlstm,xlt,xltm,xlsb,xlsx,xlsxm,xltx,xltxm
-
-        // static initialization
-        SUPPORTED_TYPE_CHECK_LIST.add("csv");
-        SUPPORTED_TYPE_CHECK_LIST.add("doc");
-        SUPPORTED_TYPE_CHECK_LIST.add("docm");
-        SUPPORTED_TYPE_CHECK_LIST.add("docx");
-        SUPPORTED_TYPE_CHECK_LIST.add("docxm");
-        SUPPORTED_TYPE_CHECK_LIST.add("dot");
-        SUPPORTED_TYPE_CHECK_LIST.add("dotm");
-        SUPPORTED_TYPE_CHECK_LIST.add("dotx");
-        SUPPORTED_TYPE_CHECK_LIST.add("dotxm");
-        SUPPORTED_TYPE_CHECK_LIST.add("fodp");
-        SUPPORTED_TYPE_CHECK_LIST.add("fods");
-        SUPPORTED_TYPE_CHECK_LIST.add("fodt");
-        SUPPORTED_TYPE_CHECK_LIST.add("html");
-        SUPPORTED_TYPE_CHECK_LIST.add("odg");
-        SUPPORTED_TYPE_CHECK_LIST.add("odgm");
-        SUPPORTED_TYPE_CHECK_LIST.add("odp");
-        SUPPORTED_TYPE_CHECK_LIST.add("odpm");
-        SUPPORTED_TYPE_CHECK_LIST.add("ods");
-        SUPPORTED_TYPE_CHECK_LIST.add("odsm");
-        SUPPORTED_TYPE_CHECK_LIST.add("odt");
-        SUPPORTED_TYPE_CHECK_LIST.add("odtm");
-        SUPPORTED_TYPE_CHECK_LIST.add("otg");
-        SUPPORTED_TYPE_CHECK_LIST.add("otgm");
-        SUPPORTED_TYPE_CHECK_LIST.add("otm");
-        SUPPORTED_TYPE_CHECK_LIST.add("ots");
-        SUPPORTED_TYPE_CHECK_LIST.add("otsm");
-        SUPPORTED_TYPE_CHECK_LIST.add("otp");
-        SUPPORTED_TYPE_CHECK_LIST.add("otpm");
-        SUPPORTED_TYPE_CHECK_LIST.add("ott");
-        SUPPORTED_TYPE_CHECK_LIST.add("ottm");
-        SUPPORTED_TYPE_CHECK_LIST.add("pot");
-        SUPPORTED_TYPE_CHECK_LIST.add("potm");
-        SUPPORTED_TYPE_CHECK_LIST.add("potx");
-        SUPPORTED_TYPE_CHECK_LIST.add("potxm");
-        SUPPORTED_TYPE_CHECK_LIST.add("pps");
-        SUPPORTED_TYPE_CHECK_LIST.add("ppt");
-        SUPPORTED_TYPE_CHECK_LIST.add("pptm");
-        SUPPORTED_TYPE_CHECK_LIST.add("pptx");
-        SUPPORTED_TYPE_CHECK_LIST.add("pptxm");
-        SUPPORTED_TYPE_CHECK_LIST.add("rtf");
-        SUPPORTED_TYPE_CHECK_LIST.add("txt");
-        SUPPORTED_TYPE_CHECK_LIST.add("xlm");
-        SUPPORTED_TYPE_CHECK_LIST.add("xls");
-        SUPPORTED_TYPE_CHECK_LIST.add("xlsb");
-        SUPPORTED_TYPE_CHECK_LIST.add("xlsm");
-        SUPPORTED_TYPE_CHECK_LIST.add("xlst");
-        SUPPORTED_TYPE_CHECK_LIST.add("xlstm");
-        SUPPORTED_TYPE_CHECK_LIST.add("xlt");
-        SUPPORTED_TYPE_CHECK_LIST.add("xltm");
-        SUPPORTED_TYPE_CHECK_LIST.add("xlsx");
-        SUPPORTED_TYPE_CHECK_LIST.add("xlsxm");
-        SUPPORTED_TYPE_CHECK_LIST.add("xltx");
-        SUPPORTED_TYPE_CHECK_LIST.add("xltxm");
-    }
 }
