@@ -48,9 +48,12 @@
 
 package com.openexchange.documentconverter.client.json;
 
+import java.io.File;
+import java.io.IOException;
 import java.io.InputStream;
 import java.util.EnumSet;
-import java.util.concurrent.atomic.AtomicLong;
+import java.util.HashMap;
+import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.json.JSONException;
@@ -63,8 +66,15 @@ import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
+import com.openexchange.documentconverter.JobPriority;
 import com.openexchange.documentconverter.NonNull;
+import com.openexchange.documentconverter.Nullable;
+import com.openexchange.documentconverter.PDFExtractor;
+import com.openexchange.documentconverter.Properties;
+import com.openexchange.documentconverter.client.impl.ClientConfig;
+import com.openexchange.documentconverter.client.impl.ClientManager;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.FileStorageCapability;
 import com.openexchange.file.storage.FileStorageFileAccess;
@@ -76,6 +86,7 @@ import com.openexchange.file.storage.composition.crypto.CryptographyMode;
 import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.groupware.attach.Attachments;
+import com.openexchange.groupware.ldap.User;
 import com.openexchange.mail.MailServletInterface;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.server.ServiceLookup;
@@ -86,7 +97,7 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-public class DocumentConverterAction implements AJAXActionService {
+public abstract class DocumentConverterAction implements AJAXActionService {
 
     // - Statics ---------------------------------------------------------------
 
@@ -94,7 +105,7 @@ public class DocumentConverterAction implements AJAXActionService {
     // The parameter list is used for the fast detection of ManagedFiles, based on
     // the set of all given attributes to create a unique identifier. The ManagedFile itself
     // is created for the speedup of chunked requests, using the same source again and again
-    static final private String[] idParamArray = { "uid", "id", "folder_id", "version", "source", "attached", "module", "cryptoAuth" };
+    final static private String[] idParamArray = { "uid", "id", "folder_id", "version", "revtag", "source", "attached", "module", "cryptoAuth", "attachmentId" };
 
     /**
      * Initializes a new {@link DocumentConverterAction}.
@@ -123,42 +134,22 @@ public class DocumentConverterAction implements AJAXActionService {
         }
     }
 
-    @Override
-    public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) {
-        return null;
-    }
-
-    /**
-     * @param e
-     */
-    void logException(Exception e) {
-        final Logger LOG = LoggerFactory.getLogger(this.getClass());
-
-        if (null != LOG) {
-            LOG.error(((null != e) && (null != e.getMessage())) ? e.getMessage() : "Unknown exception occured");
-        }
-    }
-
     /**
      * @param request
      * @param session
      * @param jobError
      * @return
      */
-    protected ManagedFile getManagedFileForRequestDocument(@NonNull final AJAXRequestData request, final @NonNull ServerSession session, @NonNull JobError[] jobError) {
+    protected ManagedFile getRequestSourceFile(@NonNull final AJAXRequestData request, final @NonNull ServerSession session, @NonNull JobError[] jobError) {
+        final FileIdLocker fileIdLocker = FileIdLocker.get(m_managedFileManagement);
         final String documentId = getDocumentId(request);
+
         ManagedFile ret = null;
 
         try {
-            FileIdLocker.lock(documentId);
+            fileIdLocker.lock(documentId);
 
-            try {
-                ret = m_managedFileManagement.contains(documentId) ? m_managedFileManagement.getByID(documentId) : null;
-            } catch (final OXException e) {
-                logException(e);
-            }
-
-            if (null == ret) {
+            if (null == (ret = getManagedFile(documentId))) {
                 final String fileId = request.getParameter("id");
                 final String source = request.getParameter("source");
                 final String attached = request.getParameter("attached");
@@ -168,8 +159,8 @@ public class DocumentConverterAction implements AJAXActionService {
                 final String cryptoAuth = request.getParameter("cryptoAuth");
                 final boolean mailCheck = ((attached != null) && (folderId != null) && (attached.length() > 0));
                 final boolean taskCheck = mailCheck && (module != null);
-                @SuppressWarnings("resource") MailServletInterface mailServletInterface = null; // closing done in finally block
-                @SuppressWarnings("resource") InputStream documentStm = null; // closing done in finally block
+                MailServletInterface mailServletInterface = null; // closing done in finally block
+                InputStream documentStm = null; // closing done in finally block
 
                 try {
                     if (mailCheck && "mail".equals(source)) {
@@ -269,12 +260,87 @@ public class DocumentConverterAction implements AJAXActionService {
                 }
             }
         } finally {
-            FileIdLocker.unlock(documentId);
+            fileIdLocker.unlock(documentId);
         }
 
         return ret;
     }
 
+    /**
+     * @param request
+     * @param session
+     * @param isAsync
+     * @param resultJobError
+     * @return
+     */
+    protected ManagedFile getPDFFile(@NonNull AJAXRequestData request, @NonNull ServerSession session, boolean isAsync, final JobError[] resultJobError) {
+        final FileIdLocker fileIdLocker = FileIdLocker.get(m_managedFileManagement);
+        final IDocumentConverter docConverter = m_services.getService(IDocumentConverter.class);
+        ManagedFile managedResultFile = null;
+
+        if (null != docConverter) {
+            final String locale = getPreferredLanguage(session);
+            final String resultDocumentId = getDocumentId(request, "pdf", locale);
+
+            try {
+                fileIdLocker.lock(resultDocumentId);
+
+                if (null == (managedResultFile = getManagedFile(resultDocumentId))) {
+                    final ManagedFile managedSourceFile = getRequestSourceFile(request, session, resultJobError);
+
+                    if(null != managedSourceFile) {
+                        final String fileName = request.getParameter("filename");
+
+                        if ((null != fileName) && "pdf".equalsIgnoreCase(FilenameUtils.getExtension(fileName))) {
+                            // return source file in case of a PDF source
+                            managedResultFile = managedSourceFile;
+                        } else {
+                            // convert to PDF
+                            final HashMap<String, Object> jobProperties = new HashMap<>(12);
+                            final HashMap<String, Object> resultProperties = new HashMap<>(8);
+
+                            jobProperties.put(Properties.PROP_INPUT_FILE, managedSourceFile.getFile());
+                            jobProperties.put(Properties.PROP_PRIORITY, JobPriority.fromString(request.getParameter("priority")));
+                            jobProperties.put(Properties.PROP_LOCALE, locale);
+
+                            if (null != fileName) {
+                                jobProperties.put(Properties.PROP_INFO_FILENAME, fileName);
+                            }
+
+                            if (isAsync) {
+                                jobProperties.put(Properties.PROP_ASYNC, Boolean.TRUE);
+                                jobProperties.put(Properties.PROP_PRIORITY, JobPriority.BACKGROUND);
+                            } else {
+                                // this is a user request in synchronous case
+                                jobProperties.put(Properties.PROP_USER_REQUEST, Boolean.TRUE);
+                            }
+
+                            try (InputStream pdfResultStm = docConverter.convert("pdf", jobProperties, resultProperties)) {
+                                if (null != pdfResultStm) {
+                                    managedResultFile = m_managedFileManagement.createManagedFile(resultDocumentId, pdfResultStm);
+                                    resultJobError[0] = JobError.NONE;
+                                } else {
+                                    resultJobError[0] = isAsync ? JobError.NONE : JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
+                                }
+                            }
+                        }
+                    } else {
+                        // async case for PDF documents
+                        resultJobError[0] = isAsync ? JobError.NONE : JobError.NO_CONTENT;
+                    }
+                }
+            } catch (Exception e) {
+                logException(e);
+            } finally {
+                fileIdLocker.unlock(resultDocumentId);
+            }
+        } else {
+            resultJobError[0] = JobError.GENERAL;
+        }
+
+        return managedResultFile;
+    }
+
     /**
      * @param request
      * @param fileHolder
@@ -318,11 +384,31 @@ public class DocumentConverterAction implements AJAXActionService {
                         break;
                     }
 
+                    case DISPOSED: {
+                        errorCause = "engineDisposed";
+                        break;
+                    }
+
                     case UNSUPPORTED: {
                         errorCause = "unsupportedType";
                         break;
                     }
 
+                    case OUT_OF_MEMORY: {
+                        errorCause = "outOfMemory";
+                        break;
+                    }
+
+                    case ABORT: {
+                        errorCause = "abort";
+                        break;
+                    }
+
+                    case PDFTOOL: {
+                        errorCause = "pdfTool";
+                        break;
+                    }
+
                     case GENERAL:
                     default: {
                         errorCause = "filterError";
@@ -344,26 +430,52 @@ public class DocumentConverterAction implements AJAXActionService {
         return ret;
     }
 
-    String getDefaultEncoding() {
-        final ConfigurationService configurationService = m_services.getOptionalService(ConfigurationService.class);
-        return null == configurationService ? "UTF-8" : configurationService.getProperty("DefaultEncoding", "UTF-8").trim();
+    /**
+     * @return
+     * @throws IOException
+     */
+    protected @Nullable PDFExtractor getPDFExtractor() throws IOException {
+        final ClientConfig clientConfig = ClientManager.get().getClientConfig();
+        final File pdfExtractorExecutable = clientConfig.PDFEXTRACTOR_EXECUTABLE_PATH;
+
+        return (null != pdfExtractorExecutable) ?
+            PDFExtractor.get(pdfExtractorExecutable, clientConfig.PDFEXTRACTOR_WORKDIR) :
+                null;
     }
 
     /**
-     * @param request
-     * @param fileHolder
+     * @param pdfInputFile
      * @return
      */
-    static AJAXRequestResult getRequestResult(@NonNull AJAXRequestData request, @NonNull IFileHolder fileHolder) {
-        request.setFormat("file");
-        return new AJAXRequestResult(fileHolder, "file");
+    protected int getPDFPageCount(@NonNull final File pdfInputFile) throws IOException {
+        final PDFExtractor pdfExtractor = getPDFExtractor();
+
+        return (null != pdfExtractor) ?
+            pdfExtractor.getPageCount(pdfInputFile) :
+                -1;
+    }
+
+    /**
+     * @param session
+     * @return
+     */
+    protected @NonNull String getPreferredLanguage(ServerSession session) {
+        final User sessionUser = session.getUser();
+        String prefLanguage = null;
+
+        // user language
+        if (null != sessionUser) {
+            prefLanguage = sessionUser.getPreferredLanguage();
+        }
+
+        return StringUtils.isBlank(prefLanguage) ? "en_US" : prefLanguage;
     }
 
     /**
      * @param request
      * @return
      */
-    static protected String getDocumentId(@NonNull AJAXRequestData request, String... additionalData) {
+    protected String getDocumentId(@NonNull AJAXRequestData request, String... additionalData) {
         final StringBuilder idBuilder = new StringBuilder(128);
         final String[][] allParamArrays = { idParamArray, additionalData };
 
@@ -387,20 +499,40 @@ public class DocumentConverterAction implements AJAXActionService {
     }
 
     /**
-     * @param fileName
-     * @param newExtension
+     * @param id
      * @return
      */
-    static protected String getReplacedExtensionFileName(String fileName, @NonNull String newExtension) {
-        final String usedFileName = StringUtils.isEmpty(fileName) ? "unknown" : fileName;
-        final int dotPos = usedFileName.lastIndexOf('.');
+    @Nullable protected ManagedFile getManagedFile(@NonNull final String id) {
+        ManagedFile ret = null;
 
-        return new StringBuffer((dotPos > -1) ? usedFileName.substring(0, dotPos + 1) : usedFileName).append(newExtension).toString();
+        try {
+            ret = m_managedFileManagement.optByID(id);
+
+            // TODO: clarify with Thorben, why this size check seems to be necessary nowadays
+            if ((null != ret) && (ret.getSize() <= 0)) {
+                ret.delete();
+                ret = null;
+            }
+        } catch (final OXException e) {
+            logException(e);
+        }
+
+        return ret;
+    }
+
+
+    /**
+     * @param e
+     */
+    protected void logException(Exception e) {
+        if (null != LOG) {
+            LOG.error(((null != e) && (null != e.getMessage())) ? e.getMessage() : "Unknown exception occured");
+        }
     }
 
     // - Members ---------------------------------------------------------------
 
-    static protected AtomicLong m_uniqueVersion = new AtomicLong(0);
+    private Logger LOG = LoggerFactory.getLogger(this.getClass());
 
     protected ServiceLookup m_services = null;
 
