@@ -77,7 +77,7 @@ import com.openexchange.conversion.DataProperties;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
-import com.openexchange.documentconverter.ManagerBasics;
+import com.openexchange.documentconverter.DocumentConverterManager;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.documentconverter.client.impl.ClientManager;
@@ -156,7 +156,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
             final DataProperties dataProperties = documentData.getDataProperties();
 
             if (null != dataProperties) {
-                final File documentFile = createTempFile(docConverter, documentData);
+                final File documentFile = createTempFile(documentData);
 
                 if (null != documentFile) {
                     String fileName = dataProperties.get(DataProperties.PROPERTY_NAME);
@@ -166,7 +166,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
                     if (!fileInputType.equals("pdf")) {
                         final String previewLanguage = detectPreviewLanguage(dataProperties.get("PreviewLanguage"), session);
-                        final HashMap<String, Object> jobProperties = new HashMap<>(10);
+                        final HashMap<String, Object> jobProperties = new HashMap<>(12);
                         final HashMap<String, Object> resultProperties = new HashMap<>(8);
 
                         jobProperties.put(Properties.PROP_INPUT_FILE, documentFile);
@@ -180,14 +180,14 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                         }
 
                         // perform an async request for PDF conversion
-                        if (ClientManager.isLogTrace()) {
-                            ClientManager.logTrace("OfficePreviewService performs asynchronous PDF conversion for document: " + ((null != fileName) ? fileName : ""));
+                        if (DocumentConverterManager.isLogTrace()) {
+                            DocumentConverterManager.logTrace("DC OfficePreviewService performs asynchronous PDF conversion for document: " + ((null != fileName) ? fileName : ""));
                         }
 
                         docConverter.convert("pdf", jobProperties, resultProperties);
                     } else {
-                        if (ClientManager.isLogTrace()) {
-                            ClientManager.logTrace("OfficePreviewService received asynchronous PDF conversion request for PDF document => no need to convert: " + ((null != fileName) ? fileName : ""));
+                        if (DocumentConverterManager.isLogTrace()) {
+                            DocumentConverterManager.logTrace("DC OfficePreviewService received asynchronous PDF conversion request for PDF document => no need to convert: " + ((null != fileName) ? fileName : ""));
                         }
                     }
 
@@ -274,7 +274,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
             try {
                 final IDocumentConverter docConverter = m_serviceLookup.getService(IDocumentConverter.class);
 
-                if ((null != docConverter) && (!cacheOnly || ClientManager.getClientConfig().PREVIEW_ENABLE_CACHE_LOOKUP) && (null != (tmpSourceFile = createTempFile(docConverter, documentData)))) {
+                if ((null != docConverter) && (!cacheOnly || ClientManager.get().getClientConfig().PREVIEW_ENABLE_CACHE_LOOKUP) && (null != (tmpSourceFile = createTempFile(documentData)))) {
                     previewDocument = getPreviewDocument(docConverter, tmpSourceFile, documentData, output, session, cacheOnly, async);
                 }
             } finally {
@@ -375,6 +375,11 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                                 jobProperties.put(Properties.PROP_INFO_FILENAME, fileName + ".thumbnail");
                             }
 
+                            // this is a user request in case of a synchronous request
+                            if (!async) {
+                                jobProperties.put(Properties.PROP_USER_REQUEST, Boolean.TRUE);
+                            }
+
                             resultProperties.clear();
 
                             try (final InputStream grfResultInputStm = docConverter.convert("graphic", jobProperties, resultProperties)) {
@@ -419,7 +424,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                     metaData.put("content-type", jpegMimeType);
                     metaData.put("resourcename", "image.jpg");
 
-                    ClientManager.logTrace("OfficePreviewService fulfills thumbnail request from thumbnail contained in document: " + ((null != fileName) ? fileName : ""));
+                    DocumentConverterManager.logTrace("DC OfficePreviewService fulfills thumbnail request from thumbnail contained in document: " + ((null != fileName) ? fileName : ""));
                     previewDocument = new DocumentConverterPreviewDocument(metaData, null, resultBuffer, Boolean.FALSE);
                 }
             }
@@ -432,12 +437,15 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                 // is set to true, the preview request is performed asynchronously and
                 if (async) {
                     jobProperties.put(Properties.PROP_ASYNC, Boolean.TRUE);
+                } else {
+                    // this is a user request in case of a synchronous request
+                    jobProperties.put(Properties.PROP_USER_REQUEST, Boolean.TRUE);
                 }
 
                 resultProperties.clear();
 
                 try {
-                    ClientManager.logTrace("OfficePreviewService converts document to create thumbnail: " + ((null != fileName) ? fileName : ""));
+                    DocumentConverterManager.logTrace("DC OfficePreviewService converts document to create thumbnail: " + ((null != fileName) ? fileName : ""));
 
                     if (null != (resultInputStm = docConverter.convert("preview", jobProperties, resultProperties))) {
                         // try to get direct access to the result buffer to avoid an array copy;
@@ -485,6 +493,8 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
             // is set to true, the preview request is performed asynchronously and
             if (async) {
                 jobProperties.put(Properties.PROP_ASYNC, Boolean.TRUE);
+            } else {
+                jobProperties.put(Properties.PROP_USER_REQUEST, Boolean.TRUE);
             }
 
             resultProperties.clear();
@@ -692,23 +702,23 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
     final protected static void handleExcp(Exception e) throws OXException {
         if (null != e) {
             if (e instanceof org.apache.poi.poifs.filesystem.OfficeXmlFileException) {
-                ClientManager.logInfo("Document ambiguity: cannot read binary document format with XML extension.");
+                DocumentConverterManager.logInfo("DC document ambiguity: cannot read binary document format with XML extension.");
             } else if (e instanceof IOException) {
                 throw PreviewExceptionCodes.IO_ERROR.create(e, e.getMessage());
             } else if (e instanceof RuntimeException) {
                 throw PreviewExceptionCodes.ERROR.create(e, e.getMessage());
             } else {
-                ClientManager.logExcp(e);
+                DocumentConverterManager.logExcp(e);
             }
         }
     }
 
     // checked: inputStm is always closed at end of method
-    final protected static File createTempFile(@NonNull IDocumentConverter docConverter, @NonNull Data<InputStream> documentData) throws OXException {
+    final protected static File createTempFile(@NonNull Data<InputStream> documentData) throws OXException {
         final InputStream inputStm = documentData.getData();
         File ret = null;
 
-        if ((null != inputStm) && (null != (ret = ManagerBasics.createTempFile(FileUtils.getTempDirectoryPath(), "oxpreview", null)))) {
+        if ((null != inputStm) && (null != (ret = DocumentConverterManager.createTempFile(FileUtils.getTempDirectoryPath(), "oxpreview", null)))) {
             try {
                 FileUtils.copyInputStreamToFile(inputStm, ret);
             } catch (IOException e) {
@@ -743,7 +753,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                     }
                 }
             } catch (IOException e) {
-                ClientManager.logExcp(e);
+                DocumentConverterManager.logExcp(e);
             }
         }
 
